==> james-project-3.7.1-source-release.zip: james-project/server/container/guice/blob/deduplication-gc/src/main/java/org/apache/james/modules/blobstore/validation/StorageStrategyModule.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.modules.blobstore.validation;

import org.apache.james.eventsourcing.eventstore.cassandra.dto.EventDTOModule;

public interface StorageStrategyModule {

    String TYPE_NAME = "storage-strategy-changed";

    EventDTOModule<StorageStrategyChanged, StorageStrategyChangedDTO> STORAGE_STRATEGY =
        EventDTOModule
            .forEvent(StorageStrategyChanged.class)
            .convertToDTO(StorageStrategyChangedDTO.class)
            .toDomainObjectConverter(StorageStrategyChangedDTO::toEvent)
            .toDTOConverter(StorageStrategyChangedDTO::from)
            .typeName(TYPE_NAME)
            .withFactory(EventDTOModule::new);
}

==> james-project-3.9.0-source-release.zip: james-project/server/container/guice/blob/deduplication-gc/src/main/java/org/apache/james/modules/blobstore/validation/StorageStrategyModule.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.modules.blobstore.validation;

import org.apache.james.eventsourcing.eventstore.dto.EventDTOModule;

public interface StorageStrategyModule {

    String TYPE_NAME = "storage-strategy-changed";

    EventDTOModule<StorageStrategyChanged, StorageStrategyChangedDTO> STORAGE_STRATEGY =
        EventDTOModule
            .forEvent(StorageStrategyChanged.class)
            .convertToDTO(StorageStrategyChangedDTO.class)
            .toDomainObjectConverter(StorageStrategyChangedDTO::toEvent)
            .toDTOConverter(StorageStrategyChangedDTO::from)
            .typeName(TYPE_NAME)
            .withFactory(EventDTOModule::new);
}
